@@ -3,199 +3,237 @@
     <name>MainWindow</name>
     <message>
         <location filename="mainwindow.ui" line="14"/>
+        <location filename="ui_mainwindow.h" line="285"/>
         <source>Program_Name</source>
         <translation>Ohjelman_Nimi</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="46"/>
+        <location filename="mainwindow.ui" line="50"/>
+        <location filename="ui_mainwindow.h" line="287"/>
         <source>Quit application</source>
         <translation>Lopeta sovellus</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="49"/>
+        <location filename="mainwindow.ui" line="53"/>
+        <location filename="ui_mainwindow.h" line="289"/>
         <source>Close</source>
         <translation>Sulje</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="56"/>
+        <location filename="mainwindow.ui" line="60"/>
+        <location filename="ui_mainwindow.h" line="291"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="72"/>
+        <location filename="mainwindow.ui" line="76"/>
+        <location filename="ui_mainwindow.h" line="294"/>
         <source>Display help </source>
         <translation>Näytä ohje</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="75"/>
+        <location filename="mainwindow.ui" line="79"/>
+        <location filename="ui_mainwindow.h" line="296"/>
         <source>Help</source>
         <translation>Ohje</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="82"/>
+        <location filename="mainwindow.ui" line="86"/>
+        <location filename="ui_mainwindow.h" line="298"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="98"/>
+        <location filename="mainwindow.ui" line="102"/>
+        <location filename="ui_mainwindow.h" line="300"/>
         <source>Back</source>
         <translation>Takaisin</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="156"/>
+        <location filename="mainwindow.ui" line="160"/>
+        <location filename="ui_mainwindow.h" line="302"/>
         <source>Next</source>
         <translation>Seuraava</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="182"/>
+        <location filename="mainwindow.ui" line="186"/>
+        <location filename="ui_mainwindow.h" line="307"/>
         <source>About this application</source>
         <translation>Tietoja tästä sovelluksesta</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="185"/>
+        <location filename="mainwindow.ui" line="189"/>
+        <location filename="ui_mainwindow.h" line="309"/>
         <source>About...</source>
         <translation>Tietoja...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="192"/>
+        <location filename="mainwindow.ui" line="196"/>
+        <location filename="ui_mainwindow.h" line="311"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="233"/>
+        <location filename="mainwindow.ui" line="237"/>
+        <location filename="ui_mainwindow.h" line="321"/>
+        <source>USB-DATA</source>
+        <translation>USB-DATA</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="244"/>
+        <location filename="ui_mainwindow.h" line="313"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"/>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Valitse kohde USB-laite&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="266"/>
-        <source>fat32</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="271"/>
-        <source>ext4</source>
-        <translation>ext4</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="276"/>
-        <source>exfat</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="281"/>
-        <source>ntfs</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="289"/>
+        <location filename="mainwindow.ui" line="267"/>
+        <location filename="ui_mainwindow.h" line="319"/>
         <source>Format</source>
         <translation>Muoto</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="309"/>
+        <location filename="mainwindow.ui" line="274"/>
+        <location filename="ui_mainwindow.h" line="320"/>
         <source>Refresh drive list</source>
         <translation>Päivitä ajuriluettelo</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="336"/>
-        <source>USB-DATA</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="343"/>
+        <location filename="mainwindow.ui" line="288"/>
+        <location filename="ui_mainwindow.h" line="322"/>
         <source>File System Label</source>
+        <translation>Tiedostojärjestelmän nimi</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="318"/>
+        <location filename="ui_mainwindow.h" line="314"/>
+        <source>fat32</source>
+        <translation>fat32</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="323"/>
+        <location filename="ui_mainwindow.h" line="315"/>
+        <source>ext4</source>
+        <translation>ext4</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="328"/>
+        <location filename="ui_mainwindow.h" line="316"/>
+        <source>exfat</source>
+        <translation>exfat</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="333"/>
+        <location filename="ui_mainwindow.h" line="317"/>
+        <source>ntfs</source>
+        <translation>ntfs</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="354"/>
+        <source>Show partitions</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="179"/>
+        <location filename="mainwindow.ui" line="361"/>
+        <source>Show all devices</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="181"/>
         <source>Success</source>
         <translation>Onnistui</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="179"/>
+        <location filename="mainwindow.cpp" line="181"/>
         <source>Format successful!</source>
-        <translation type="unfinished"/>
+        <translation>Alustaminen onnistui!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="181"/>
+        <location filename="mainwindow.cpp" line="183"/>
         <source>Failure</source>
         <translation>Virhe</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="181"/>
+        <location filename="mainwindow.cpp" line="183"/>
         <source>Error encountered in the Format process</source>
-        <translation type="unfinished"/>
+        <translation>Virhe havaittu alustamisen aikana</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="228"/>
+        <location filename="mainwindow.cpp" line="236"/>
         <source>Error</source>
         <translation>Virhe</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="228"/>
+        <location filename="mainwindow.cpp" line="236"/>
         <source>Please select a USB device to write to</source>
         <translation>Ole hyvä ja valitse USB-laite, jolle kirjoitetaan</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="234"/>
+        <location filename="mainwindow.cpp" line="242"/>
         <source>These actions will destroy all data on 
 
 </source>
-        <translation type="unfinished"/>
+        <translation>Nämä toimet tuhoavat kaikki tiedot kohteessa 
+
+</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="234"/>
+        <location filename="mainwindow.cpp" line="242"/>
         <source>Do you wish to continue?</source>
-        <translation type="unfinished"/>
+        <translation>Haluatko jatkaa?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="276"/>
-        <source>About</source>
-        <translation>Tietoja</translation>
+        <location filename="mainwindow.cpp" line="282"/>
+        <source>About %1</source>
+        <translation>%1 lisätietoja</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="277"/>
+        <location filename="mainwindow.cpp" line="283"/>
         <source>Version: </source>
         <translation>Versio: </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="278"/>
+        <location filename="mainwindow.cpp" line="284"/>
         <source>Program for formatting USB devices</source>
-        <translation type="unfinished"/>
+        <translation>Ohjelma USB-laitteiden alustamista varten</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="280"/>
+        <location filename="mainwindow.cpp" line="286"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="281"/>
-        <location filename="mainwindow.cpp" line="293"/>
-        <source>License</source>
-        <translation>Lisenssi</translation>
+        <location filename="mainwindow.cpp" line="287"/>
+        <source>%1 License</source>
+        <translation>%1 lupa</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="282"/>
-        <source>Changelog</source>
-        <translation>Muutosloki</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="283"/>
-        <source>Cancel</source>
-        <translation>Peru</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="305"/>
-        <source>&amp;Close</source>
-        <translation>&amp;Sulje</translation>
+        <location filename="mainwindow.cpp" line="295"/>
+        <source>%1 Help</source>
+        <translation>%1 Apuopas</translation>
     </message>
 </context>
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="main.cpp" line="79"/>
-        <source>You must run this program as root.</source>
-        <translation>Sinun täytyy suorittaa tämä ohjelma pääkäyttäjänä.</translation>
+        <location filename="about.cpp" line="38"/>
+        <source>License</source>
+        <translation>Lisenssi</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="39"/>
+        <location filename="about.cpp" line="49"/>
+        <source>Changelog</source>
+        <translation>Muutosloki</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="40"/>
+        <source>Cancel</source>
+        <translation>Peru</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="57"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Sulje</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
